@@ -36,9 +36,16 @@ __all__ = (
     "ActionExecutionTypeDef",
     "ActionRevisionTypeDef",
     "ActionStateTypeDef",
+    "ActionTypeArtifactDetailsTypeDef",
+    "ActionTypeDeclarationTypeDef",
+    "ActionTypeExecutorTypeDef",
     "ActionTypeIdTypeDef",
+    "ActionTypeIdentifierTypeDef",
+    "ActionTypePermissionsTypeDef",
+    "ActionTypePropertyTypeDef",
     "ActionTypeSettingsTypeDef",
     "ActionTypeTypeDef",
+    "ActionTypeUrlsTypeDef",
     "ArtifactDetailTypeDef",
     "ArtifactDetailsTypeDef",
     "ArtifactLocationTypeDef",
@@ -49,10 +56,13 @@ __all__ = (
     "EncryptionKeyTypeDef",
     "ErrorDetailsTypeDef",
     "ExecutionTriggerTypeDef",
+    "ExecutorConfigurationTypeDef",
     "InputArtifactTypeDef",
     "JobDataTypeDef",
     "JobDetailsTypeDef",
     "JobTypeDef",
+    "JobWorkerExecutorConfigurationTypeDef",
+    "LambdaExecutorConfigurationTypeDef",
     "ListWebhookItemTypeDef",
     "OutputArtifactTypeDef",
     "PipelineContextTypeDef",
@@ -87,6 +97,7 @@ __all__ = (
     "CurrentRevisionTypeDef",
     "ExecutionDetailsTypeDef",
     "FailureDetailsTypeDef",
+    "GetActionTypeOutputTypeDef",
     "GetJobDetailsOutputTypeDef",
     "GetPipelineExecutionOutputTypeDef",
     "GetPipelineOutputTypeDef",
@@ -245,6 +256,54 @@ ActionStateTypeDef = TypedDict(
     total=False,
 )
 
+ActionTypeArtifactDetailsTypeDef = TypedDict(
+    "ActionTypeArtifactDetailsTypeDef", {"minimumCount": int, "maximumCount": int}
+)
+
+_RequiredActionTypeDeclarationTypeDef = TypedDict(
+    "_RequiredActionTypeDeclarationTypeDef",
+    {
+        "executor": "ActionTypeExecutorTypeDef",
+        "id": "ActionTypeIdentifierTypeDef",
+        "inputArtifactDetails": "ActionTypeArtifactDetailsTypeDef",
+        "outputArtifactDetails": "ActionTypeArtifactDetailsTypeDef",
+    },
+)
+_OptionalActionTypeDeclarationTypeDef = TypedDict(
+    "_OptionalActionTypeDeclarationTypeDef",
+    {
+        "description": str,
+        "permissions": "ActionTypePermissionsTypeDef",
+        "properties": List["ActionTypePropertyTypeDef"],
+        "urls": "ActionTypeUrlsTypeDef",
+    },
+    total=False,
+)
+
+
+class ActionTypeDeclarationTypeDef(
+    _RequiredActionTypeDeclarationTypeDef, _OptionalActionTypeDeclarationTypeDef
+):
+    pass
+
+
+_RequiredActionTypeExecutorTypeDef = TypedDict(
+    "_RequiredActionTypeExecutorTypeDef",
+    {"configuration": "ExecutorConfigurationTypeDef", "type": Literal["JobWorker", "Lambda"]},
+)
+_OptionalActionTypeExecutorTypeDef = TypedDict(
+    "_OptionalActionTypeExecutorTypeDef",
+    {"policyStatementsTemplate": str, "jobTimeout": int},
+    total=False,
+)
+
+
+class ActionTypeExecutorTypeDef(
+    _RequiredActionTypeExecutorTypeDef, _OptionalActionTypeExecutorTypeDef
+):
+    pass
+
+
 ActionTypeIdTypeDef = TypedDict(
     "ActionTypeIdTypeDef",
     {
@@ -255,6 +314,35 @@ ActionTypeIdTypeDef = TypedDict(
     },
 )
 
+ActionTypeIdentifierTypeDef = TypedDict(
+    "ActionTypeIdentifierTypeDef",
+    {
+        "category": Literal["Source", "Build", "Deploy", "Test", "Invoke", "Approval"],
+        "owner": str,
+        "provider": str,
+        "version": str,
+    },
+)
+
+ActionTypePermissionsTypeDef = TypedDict(
+    "ActionTypePermissionsTypeDef", {"allowedAccounts": List[str]}
+)
+
+_RequiredActionTypePropertyTypeDef = TypedDict(
+    "_RequiredActionTypePropertyTypeDef",
+    {"name": str, "optional": bool, "key": bool, "noEcho": bool},
+)
+_OptionalActionTypePropertyTypeDef = TypedDict(
+    "_OptionalActionTypePropertyTypeDef", {"queryable": bool, "description": str}, total=False
+)
+
+
+class ActionTypePropertyTypeDef(
+    _RequiredActionTypePropertyTypeDef, _OptionalActionTypePropertyTypeDef
+):
+    pass
+
+
 ActionTypeSettingsTypeDef = TypedDict(
     "ActionTypeSettingsTypeDef",
     {
@@ -288,6 +376,17 @@ class ActionTypeTypeDef(_RequiredActionTypeTypeDef, _OptionalActionTypeTypeDef):
     pass
 
 
+ActionTypeUrlsTypeDef = TypedDict(
+    "ActionTypeUrlsTypeDef",
+    {
+        "configurationUrl": str,
+        "entityUrlTemplate": str,
+        "executionUrlTemplate": str,
+        "revisionUrlTemplate": str,
+    },
+    total=False,
+)
+
 ArtifactDetailTypeDef = TypedDict(
     "ArtifactDetailTypeDef", {"name": str, "s3location": "S3LocationTypeDef"}, total=False
 )
@@ -357,6 +456,15 @@ ExecutionTriggerTypeDef = TypedDict(
     total=False,
 )
 
+ExecutorConfigurationTypeDef = TypedDict(
+    "ExecutorConfigurationTypeDef",
+    {
+        "lambdaExecutorConfiguration": "LambdaExecutorConfigurationTypeDef",
+        "jobWorkerExecutorConfiguration": "JobWorkerExecutorConfigurationTypeDef",
+    },
+    total=False,
+)
+
 InputArtifactTypeDef = TypedDict("InputArtifactTypeDef", {"name": str})
 
 JobDataTypeDef = TypedDict(
@@ -382,6 +490,16 @@ JobTypeDef = TypedDict(
     "JobTypeDef", {"id": str, "data": "JobDataTypeDef", "nonce": str, "accountId": str}, total=False
 )
 
+JobWorkerExecutorConfigurationTypeDef = TypedDict(
+    "JobWorkerExecutorConfigurationTypeDef",
+    {"pollingAccounts": List[str], "pollingServicePrincipals": List[str]},
+    total=False,
+)
+
+LambdaExecutorConfigurationTypeDef = TypedDict(
+    "LambdaExecutorConfigurationTypeDef", {"lambdaFunctionArn": str}
+)
+
 _RequiredListWebhookItemTypeDef = TypedDict(
     "_RequiredListWebhookItemTypeDef", {"definition": "WebhookDefinitionTypeDef", "url": str}
 )
@@ -705,6 +823,12 @@ class FailureDetailsTypeDef(_RequiredFailureDetailsTypeDef, _OptionalFailureDeta
     pass
 
 
+GetActionTypeOutputTypeDef = TypedDict(
+    "GetActionTypeOutputTypeDef",
+    {"actionType": "ActionTypeDeclarationTypeDef", "ResponseMetadata": "ResponseMetadata"},
+    total=False,
+)
+
 GetJobDetailsOutputTypeDef = TypedDict(
     "GetJobDetailsOutputTypeDef",
     {"jobDetails": "JobDetailsTypeDef", "ResponseMetadata": "ResponseMetadata"},
